@@ -19,8 +19,10 @@
  * License along with this library; if not, see <http://www.gnu.org/licenses/>.
  */
 
-#include "pygi-private.h"
-#include "pygobject-private.h"
+#include "pygi-boxed.h"
+#include "pygi-info.h"
+#include "pygboxed.h"
+#include "pygtype.h"
 
 #include <girepository.h>
 #include <pyglib-python-compat.h>
