@@ -21,9 +21,17 @@
 #define __PYGI_BOXED_H__
 
 #include <Python.h>
+#include <girepository.h>
+#include "pygobject-internal.h"
 
 G_BEGIN_DECLS
 
+typedef struct {
+    PyGBoxed base;
+    gboolean slice_allocated;
+    gsize size;
+} PyGIBoxed;
+
 extern PyTypeObject PyGIBoxed_Type;
 
 PyObject * _pygi_boxed_new (PyTypeObject *pytype,
