@@ -19,8 +19,7 @@
  * License along with this library; if not, see <http://www.gnu.org/licenses/>.
  */
 
-#include "pygi-private.h"
-#include "pygobject-private.h"
+#include "pygi-ccallback.h"
 
 #include <girepository.h>
 #include <pyglib-python-compat.h>
