@@ -19,7 +19,8 @@
  * License along with this library; if not, see <http://www.gnu.org/licenses/>.
  */
 
-#include "pygi-private.h"
+#include "pygi-repository.h"
+#include "pygi-info.h"
 
 #include <pyglib-python-compat.h>
 
