@@ -1,10 +1,15 @@
+import os
+import sys
 import unittest
 
 try:
-    from gi.repository import Atk, Gdk, Gtk
-    (Atk, Gdk)  # pyflakes
-except:
+    from gi.repository import Gtk, Atk, Gdk
+except ImportError:
     Gdk = None
+    Atk = None
+    Gtk = None
+
+from helper import capture_glib_deprecation_warnings
 
 
 @unittest.skipUnless(Gdk, 'Gdk not available')
@@ -51,6 +56,7 @@ class TestGdkAtom(unittest.TestCase):
         self.assertTrue(Gtk.targets_include_image([a_jpeg], False))
         self.assertTrue(Gtk.targets_include_image([a_jpeg, a_plain], False))
 
+    @unittest.skipIf(sys.platform == "darwin", "fails on OSX")
     def test_out_array(self):
         a_selection = Gdk.Atom.intern('my_clipboard', False)
         clipboard = Gtk.Clipboard.get(a_selection)
@@ -70,10 +76,14 @@ class TestGdkAtom(unittest.TestCase):
         self.assertFalse(None in names, names)
         self.assertTrue('TEXT' in names, names)
 
+    @unittest.skipIf(sys.platform == "darwin" or os.name == "nt",
+                     "fails on OSX/Windows")
+    @unittest.skipIf(not Gdk or Gdk._version == "4.0", "not in gdk4")
     def test_out_glist(self):
         display = Gdk.Display.get_default()
-        dm = display.get_device_manager()
-        device = dm.get_client_pointer()
+        with capture_glib_deprecation_warnings():
+            dm = display.get_device_manager()
+            device = dm.get_client_pointer()
         axes = device.list_axes()
         axes_names = [atom.name() for atom in axes]
         self.assertNotEqual(axes_names, [])
