@@ -1,9 +1,12 @@
 # -*- Mode: Python; py-indent-offset: 4 -*-
 # vim: tabstop=4 shiftwidth=4 expandtab
 
+import os
 import unittest
+import warnings
 
 import gi.overrides
+from gi import PyGIWarning
 from gi.repository import GLib, Gio
 
 from helper import ignore_gi_deprecation_warnings
@@ -39,6 +42,15 @@ class TestGio(unittest.TestCase):
         value = menu.get_item_attribute_value(0, "action", GLib.VariantType.new("s"))
         self.assertEqual("app.test", value.unpack())
 
+    def test_volume_monitor_warning(self):
+        with warnings.catch_warnings(record=True) as warn:
+            warnings.simplefilter('always')
+            Gio.VolumeMonitor()
+            self.assertEqual(len(warn), 1)
+            self.assertTrue(issubclass(warn[0].category, PyGIWarning))
+            self.assertRegexpMatches(str(warn[0].message),
+                                     '.*Gio\\.VolumeMonitor\\.get\\(\\).*')
+
 
 class TestGSettings(unittest.TestCase):
     def setUp(self):
@@ -142,6 +154,7 @@ class TestGSettings(unittest.TestCase):
                                              1)])
 
 
+@unittest.skipIf(os.name == "nt", "FIXME")
 class TestGFile(unittest.TestCase):
     def setUp(self):
         self.file, self.io_stream = Gio.File.new_tmp('TestGFile.XXXXXX')
@@ -206,6 +219,7 @@ class TestGFile(unittest.TestCase):
         self.assertFalse(self.file.query_exists(None))
 
 
+@unittest.skipIf(os.name == "nt", "crashes on Windows")
 class TestGApplication(unittest.TestCase):
     def test_command_line(self):
         class App(Gio.Application):
