@@ -1,12 +1,13 @@
 # coding=utf-8
 
+import os
 import gc
 import sys
 import struct
 import types
 import unittest
+import tempfile
 
-import gi
 from gi.repository import GObject
 from gi.repository.GObject import ParamFlags, GType, new
 from gi.repository.GObject import \
@@ -22,25 +23,11 @@ from gi.repository.GLib import \
 
 from gi.repository import Gio
 from gi.repository import GLib
-gi.require_version('GIMarshallingTests', '1.0')
 from gi.repository import GIMarshallingTests
+from gi.repository import Regress
 from gi import _propertyhelper as propertyhelper
 
-try:
-    gi.require_version('Regress', '1.0')
-    from gi.repository import Regress
-    has_regress = True
-except (ValueError, ImportError):
-    has_regress = False
-
-if sys.version_info < (3, 0):
-    TEST_UTF8 = "\xe2\x99\xa5"
-    UNICODE_UTF8 = unicode(TEST_UTF8, 'UTF-8')
-else:
-    TEST_UTF8 = "♥"
-    UNICODE_UTF8 = TEST_UTF8
-
-from compathelper import _long, _unicode
+from compathelper import _long
 from helper import capture_glib_warnings, capture_output
 
 
@@ -93,20 +80,19 @@ class PropertyObject(GObject.GObject):
         flags=ParamFlags.READABLE | ParamFlags.WRITABLE | ParamFlags.CONSTRUCT)
 
 
-if has_regress:
-    class PropertyInheritanceObject(Regress.TestObj):
-        # override property from the base class, with a different type
-        string = GObject.Property(type=int)
+class PropertyInheritanceObject(Regress.TestObj):
+    # override property from the base class, with a different type
+    string = GObject.Property(type=int)
 
-        # a property entirely defined at the Python level
-        python_prop = GObject.Property(type=str)
+    # a property entirely defined at the Python level
+    python_prop = GObject.Property(type=str)
 
-    class PropertySubClassObject(PropertyInheritanceObject):
-        # override property from the base class, with a different type
-        python_prop = GObject.Property(type=int)
+
+class PropertySubClassObject(PropertyInheritanceObject):
+    # override property from the base class, with a different type
+    python_prop = GObject.Property(type=int)
 
 
-@unittest.skipUnless(has_regress, 'Missing Regress typelib')
 class TestPropertyInheritanceObject(unittest.TestCase):
     def test_override_gi_property(self):
         self.assertNotEqual(Regress.TestObj.props.string.value_type,
@@ -181,12 +167,14 @@ class TestPropertyObject(unittest.TestCase):
         self.assertEqual(obj.props.construct, "789")
 
     def test_utf8(self):
-        obj = new(PropertyObject, construct_only=UNICODE_UTF8)
-        self.assertEqual(obj.props.construct_only, TEST_UTF8)
-        obj.set_property('construct', UNICODE_UTF8)
-        self.assertEqual(obj.props.construct, TEST_UTF8)
-        obj.props.normal = UNICODE_UTF8
-        self.assertEqual(obj.props.normal, TEST_UTF8)
+        test_utf8 = "♥"
+        unicode_utf8 = u"♥"
+        obj = new(PropertyObject, construct_only=unicode_utf8)
+        self.assertEqual(obj.props.construct_only, test_utf8)
+        obj.set_property('construct', unicode_utf8)
+        self.assertEqual(obj.props.construct, test_utf8)
+        obj.props.normal = unicode_utf8
+        self.assertEqual(obj.props.normal, test_utf8)
 
     def test_int_to_str(self):
         obj = new(PropertyObject, construct_only=1)
@@ -417,10 +405,11 @@ class TestPropertyObject(unittest.TestCase):
     def test_interface(self):
         obj = new(PropertyObject)
 
-        file = Gio.File.new_for_path('/some/path')
+        path = os.path.join(tempfile.gettempdir(), "some", "path")
+        file = Gio.File.new_for_path(path)
         obj.props.interface = file
-        self.assertEqual(obj.props.interface.get_path(), '/some/path')
-        self.assertEqual(obj.interface.get_path(), '/some/path')
+        self.assertEqual(obj.props.interface.get_path(), path)
+        self.assertEqual(obj.interface.get_path(), path)
 
         self.assertRaises(TypeError, setattr, obj, 'interface', 'foo')
         self.assertRaises(TypeError, setattr, obj, 'interface', object())
@@ -766,7 +755,6 @@ class TestProperty(unittest.TestCase):
         b.prop1 = 20
         self.assertEqual(b.prop1, 20)
 
-    @unittest.skipUnless(has_regress, 'Missing regress typelib')
     def test_property_subclass_c(self):
         class A(Regress.TestSubObj):
             prop1 = GObject.Property(type=int)
@@ -970,6 +958,40 @@ class CPropertiesTestBase(object):
     def set_prop(self, obj, name, value):
         raise NotImplementedError
 
+    # https://bugzilla.gnome.org/show_bug.cgi?id=780652
+    @unittest.skipUnless(
+        "some_flags" in dir(GIMarshallingTests.PropertiesObject.props),
+        "tool old gi")
+    def test_flags(self):
+        self.assertEqual(
+            self.get_prop(self.obj, 'some-flags'),
+            GIMarshallingTests.Flags.VALUE1)
+        self.set_prop(self.obj, 'some-flags', GIMarshallingTests.Flags.VALUE2)
+        self.assertEqual(self.get_prop(self.obj, 'some-flags'),
+                         GIMarshallingTests.Flags.VALUE2)
+
+        obj = GIMarshallingTests.PropertiesObject(
+            some_flags=GIMarshallingTests.Flags.VALUE3)
+        self.assertEqual(self.get_prop(obj, 'some-flags'),
+                         GIMarshallingTests.Flags.VALUE3)
+
+    # https://bugzilla.gnome.org/show_bug.cgi?id=780652
+    @unittest.skipUnless(
+        "some_enum" in dir(GIMarshallingTests.PropertiesObject.props),
+        "tool old gi")
+    def test_enum(self):
+        self.assertEqual(
+            self.get_prop(self.obj, 'some-enum'),
+            GIMarshallingTests.GEnum.VALUE1)
+        self.set_prop(self.obj, 'some-enum', GIMarshallingTests.GEnum.VALUE2)
+        self.assertEqual(self.get_prop(self.obj, 'some-enum'),
+                         GIMarshallingTests.GEnum.VALUE2)
+
+        obj = GIMarshallingTests.PropertiesObject(
+            some_enum=GIMarshallingTests.GEnum.VALUE3)
+        self.assertEqual(self.get_prop(obj, 'some-enum'),
+                         GIMarshallingTests.GEnum.VALUE3)
+
     def test_boolean(self):
         self.assertEqual(self.get_prop(self.obj, 'some-boolean'), False)
         self.set_prop(self.obj, 'some-boolean', True)
@@ -1110,10 +1132,10 @@ class CPropertiesTestBase(object):
         self.assertEqual(self.get_prop(obj, 'some-strv'), ['hello', 'world'])
 
         # unicode on py2
-        obj = GIMarshallingTests.PropertiesObject(some_strv=[_unicode('foo')])
-        self.assertEqual(self.get_prop(obj, 'some-strv'), [_unicode('foo')])
+        obj = GIMarshallingTests.PropertiesObject(some_strv=[u'foo'])
+        self.assertEqual(self.get_prop(obj, 'some-strv'), [u'foo'])
         self.assertRaises(TypeError, self.set_prop, self.obj, 'some-strv',
-                          [_unicode('foo'), 1])
+                          [u'foo', 1])
 
     def test_boxed_struct(self):
         self.assertEqual(self.get_prop(self.obj, 'some-boxed-struct'), None)
@@ -1137,9 +1159,9 @@ class CPropertiesTestBase(object):
     def test_boxed_glist(self):
         self.assertEqual(self.get_prop(self.obj, 'some-boxed-glist'), [])
 
-        l = [GLib.MININT, 42, GLib.MAXINT]
-        self.set_prop(self.obj, 'some-boxed-glist', l)
-        self.assertEqual(self.get_prop(self.obj, 'some-boxed-glist'), l)
+        list_ = [GLib.MININT, 42, GLib.MAXINT]
+        self.set_prop(self.obj, 'some-boxed-glist', list_)
+        self.assertEqual(self.get_prop(self.obj, 'some-boxed-glist'), list_)
         self.set_prop(self.obj, 'some-boxed-glist', [])
         self.assertEqual(self.get_prop(self.obj, 'some-boxed-glist'), [])
 
@@ -1147,7 +1169,6 @@ class CPropertiesTestBase(object):
         self.assertRaises(TypeError, self.set_prop, self.obj, 'some-boxed-glist', 'foo')
         self.assertRaises(TypeError, self.set_prop, self.obj, 'some-boxed-glist', ['a'])
 
-    @unittest.skipUnless(has_regress, 'built without cairo support')
     def test_annotated_glist(self):
         obj = Regress.TestObj()
         self.assertEqual(self.get_prop(obj, 'list'), [])
@@ -1158,9 +1179,9 @@ class CPropertiesTestBase(object):
 
     @unittest.expectedFailure
     def test_boxed_glist_ctor(self):
-        l = [GLib.MININT, 42, GLib.MAXINT]
-        obj = GIMarshallingTests.PropertiesObject(some_boxed_glist=l)
-        self.assertEqual(self.get_prop(obj, 'some-boxed-glist'), l)
+        list_ = [GLib.MININT, 42, GLib.MAXINT]
+        obj = GIMarshallingTests.PropertiesObject(some_boxed_glist=list_)
+        self.assertEqual(self.get_prop(obj, 'some-boxed-glist'), list_)
 
     def test_variant(self):
         self.assertEqual(self.get_prop(self.obj, 'some-variant'), None)
@@ -1188,7 +1209,6 @@ class CPropertiesTestBase(object):
         self.assertEqual(42, self.get_prop(obj, 'some-int'))
         self.assertEqual(54, self.get_prop(obj, 'some-uchar'))
 
-    @unittest.skipUnless(has_regress, 'built without cairo support')
     def test_gtype(self):
         obj = Regress.TestObj()
         self.assertEqual(self.get_prop(obj, 'gtype'), GObject.TYPE_INVALID)
@@ -1200,7 +1220,6 @@ class CPropertiesTestBase(object):
         self.set_prop(obj, 'gtype', str)
         self.assertEqual(self.get_prop(obj, 'gtype'), GObject.TYPE_STRING)
 
-    @unittest.skipUnless(has_regress, 'built without cairo support')
     def test_hash_table(self):
         obj = Regress.TestObj()
         self.assertEqual(self.get_prop(obj, 'hash-table'), None)
@@ -1210,7 +1229,6 @@ class CPropertiesTestBase(object):
         self.assertEqual(list(self.get_prop(obj, 'hash-table').items())[0],
                          ('mec', 56))
 
-    @unittest.skipUnless(has_regress, 'built without cairo support')
     def test_parent_class(self):
         class A(Regress.TestObj):
             prop1 = GObject.Property(type=int)
